HPOlib2
=======

HPOlib2 is a library for hyperparameter optimization and black box optimization
benchmarks.

HPOlib2 is under active construction. Stay tuned for more benchmarks.
Contributions of your benchmarks are welcome.

Documentation can be found on our [github page](https://automl.github.io/HPOlib2).

Status for master branch:

[![Build Status](https://travis-ci.org/automl/HPOlib2.svg?branch=master)](https://travis-ci.org/automl/HPOlib2)
[![Code Health](https://landscape.io/github/automl/HPOlib2/master/landscape.svg?style=flat)](https://landscape.io/github/automl/HPOlib2/master)
[![codecov Status](https://codecov.io/gh/automl/HPOlib2/branch/master/graph/badge.svg)](https://codecov.io/gh/automl/HPOlib2)

Status for development branch

[![Build Status](https://travis-ci.org/automl/HPOlib2.svg?branch=development)](https://travis-ci.org/automl/HPOlib2)
[![Code Health](https://landscape.io/github/automl/HPOlib2/development/landscape.svg?style=flat)](https://landscape.io/github/automl/SMAC3/development)
[![codecov Status](https://codecov.io/gh/automl/HPOlib2/branch/development/graph/badge.svg)](https://codecov.io/gh/automl/HPOlib2)

